@@ -1,12 +1,12 @@
 #' Download data on the candidates' background in local elections
 #'
-#' \code{candidate_local()} downloads and aggregates the data on the candidates' background who vied
+#' \code{candidate_local()} downloads and aggregates the data on the candidates' background who competed in the
 #' local elections in Brazil. The function returns a \code{data.frame} where each observation
 #' corresponds to a candidate.
 #'
 #' @note For the elections prior to 2000, some information can be incomplete.
 #'
-#' @param year Election year. For this function, only the years of 1996, 2000, 2004, 2008, 2012, 2016, and 2020
+#' @param year Election year. For this function, only the years of 1996, 2000, 2004, 2008, 2012, 2016, 2020, and 2024
 #' are available.
 #' 
 #' @param uf Federation Unit acronym (\code{character vector}).
@@ -37,7 +37,7 @@ candidate_local <- function(year,
                             encoding = "latin1", 
                             temp = TRUE){
 
-  .Deprecated("elections_tse", msg = "candidate_local is deprecated. Please use the elections_tse function")
+  .Deprecated("elections_tse", msg = "candidate_local is deprecated and will no longer be supported in electionsBR 1.0.0. Please use the elections_tse function")
   
   answer <- candidate(year,
                       uf,
