@@ -6,7 +6,7 @@
 #'
 #' @note For the elections prior to 2000, some information can be incomplete.
 #'
-#' @param year Election year. For this function, only the years of 1998, 2002, 2006, 2010, 2014 and 2018
+#' @param year Election year. For this function, only the years of 1998, 2002, 2006, 2010, 2014, 2018, and 2022
 #' are available.
 #' 
 #' @param uf Federation Unit acronym (\code{character} vector).
@@ -41,7 +41,7 @@ seats_fed <- function(year, uf = "all",
                       temp = TRUE){
   
   
-  .Deprecated("elections_tse", msg = "seats_fed is deprecated. Please use the elections_tse function")
+  .Deprecated("elections_tse", msg = "seats_fed is deprecated and will no longer be supported in electionsBR 1.0.0. Please use the elections_tse function")
   
   answer <- seats(year, 
                   uf, 
