@@ -116,9 +116,24 @@ parties_br <- function(year) {
                 "PSL", "CIDADANIA", "PSC", "PTB", "PC do B", "REPUBLICANOS", "DEM",
                 "PSOL", "PATRIOTA", "PCO", "AVANTE", "PODE", "DC", "PMB", "PV",
                 "PMN", "PCB", "PRTB", "REDE", "PTC", "UP", "PSTU", "NOVO")
+ 
+  } else if (year == 2022) {
 
+    result <- c("PSB", "PC do B", "SOLIDARIEDADE", "PT", "PSOL", "PODE", "DC", 
+                "PATRIOTA", "CIDADANIA", "PL", "PDT", "AGIR", "PMN", "PROS", 
+                "MDB", "PSDB", "PSD", "REPUBLICANOS", "UNIAO", "PP", "PV", "REDE", 
+                "PSC", "PTB", "PCO", "AVANTE", "PRTB", "PMB", "UP", "PSTU", "NOVO", 
+                "PCB")
+
+  } else if (year == 2024) {
+
+    result <- c("UNIAO", "PSDB", "SOLIDARIEDADE", "MDB", "REPUBLICANOS", "PL", 
+                "PP", "PDT", "PODE", "CIDADANIA", "PT", "PSD", "PSOL", "PC do B", 
+                "PRD", "DC", "PV", "REDE", "PSB", "AGIR", "NOVO", "AVANTE", "PMB", 
+                "PCO", "UP", "MOBILIZA", "PRTB", "PSTU", "PCB")
   }
 
+
   return(result)
 }
 
@@ -141,6 +156,8 @@ juntaDados <- function(uf, encoding, br_archive){
      
      archive <- archive[grepl("BR\\.|BRASIL", archive) == TRUE]
    }
+
+ 
    
    if(grepl(".csv", archive[1])){
      test_col_names <- TRUE
@@ -173,27 +190,34 @@ to_ascii <- function(banco, encoding){
 # Tests election year inputs
 test_year <- function(year){
 
-  if (!is.numeric(year) | length(year) != 1 | !year %in% seq(1998, 2022, 2)) stop("Invalid input. Please, check the documentation and try again.")
+  if (!is.numeric(year) | length(year) != 1 | !year %in% seq(1998, 2024, 2)) stop("Invalid input. Please, check the documentation and try again.")
+}
+
+# Tests election year inputs
+test_year_cand_add_infor <- function(year){
+  
+  if (!is.numeric(year) | length(year) != 1 | !year %in% seq(2024, 2024, 2)) stop("Invalid input. Please, check the documentation and try again.")
 }
 
 
 # Tests federal election year inputs
 test_fed_year <- function(year){
   
-  if(!is.numeric(year) | length(year) != 1 | !year %in% seq(1998, 2018, 4)) stop("Invalid input. Please, check the documentation and try again.")
+  if(!is.numeric(year) | length(year) != 1 | !year %in% seq(1998, 2022, 4)) stop("Invalid input. Please, check the documentation and try again.")
 }
 
 
-# Tests federal election year inputs
+# Tests local election year inputs
 test_local_year <- function(year){
   
-  if(!is.numeric(year) | length(year) != 1 | !year %in% seq(2000, 2016, 4)) stop("Invalid input. Please, check the documentation and try again.")
+  if(!is.numeric(year) | length(year) != 1 | !year %in% seq(2000, 2024, 4)) stop("Invalid input. Please, check the documentation and try again.")
 }
 
 
 test_type <- function(type){
   
   if(!is.character(type) | length(type) != 1 | !type %in% c("candidate",
+                                                            "candidate_add_infor",
                                                             "vote_mun_zone",
                                                             "details_mun_zone",
                                                             "legends",
